# Jarvis 内置规则列表

本目录包含以下分类的规则文件，每个分类对应一个子目录。

> **注意**：本文档仅列出通用规则索引。特定领域的规则（如转译规则、语言特定规则、UI设计规则等）仍然存在于对应目录中，可通过 `load_rule` 工具直接加载使用。

## 架构设计 (architecture_design/)

- [SOLID 设计原则]({{ rule_file_dir }}/architecture_design/solid.md)
- [整洁架构]({{ rule_file_dir }}/architecture_design/clean_architecture.md)
- [整洁代码]({{ rule_file_dir }}/architecture_design/clean_code.md)
- [反向工程规则]({{ rule_file_dir }}/architecture_design/reverse_engineering.md)
- [架构图生成规则]({{ rule_file_dir }}/architecture_design/architecture-diagram-generation.md)

## 开发流程 (development_workflow/)

- [Spec 驱动开发 (SDD)]({{ rule_file_dir }}/development_workflow/sdd.md)
- [测试驱动开发 (TDD)]({{ rule_file_dir }}/development_workflow/tdd.md)
- [重构]({{ rule_file_dir }}/development_workflow/refactoring.md)

## 代码质量 (code_quality/)

- [代码审查]({{ rule_file_dir }}/code_quality/code_review.md)
- [文档编写]({{ rule_file_dir }}/code_quality/documentation.md)
- [重构检查专家]({{ rule_file_dir }}/code_quality/refactor-checker.md)

## 安全规范 (security/)

- [安全编码]({{ rule_file_dir }}/security/security.md)
- [安全漏洞分析规则]({{ rule_file_dir }}/security/vulnerability-analysis.md)

## 开发工具 (development_tools/)

- [脚本生成规则]({{ rule_file_dir }}/development_tools/script-generation.md)
- [Jarvis 帮助规则]({{ rule_file_dir }}/development_tools/jarvis_help.md)

## 性能优化 (performance/)

- [性能优化]({{ rule_file_dir }}/performance/performance.md)
